from math import exp

class Neurone:
    def __init__(self, rate = 0.01):
        self.w11 = 0.0
        self.w22 = 0.0
        self.x11 = 0
        self.x22 = 0
        self.b = 0
        self.wb = 0
        self.rate = rate
        self.out = 0
        self.sumw = 0
    def sigmoid(self):
        self.out = (1 / (1 + exp(-self.sumw)))
    def wsum(self):
        self.sumw = self.b * self.wb + (self.x11 * self.w11 + self.x22 * self.w22)
    def grlearn(self):
        self.w11 += self.rate
        self.w22 += self.rate
        self.wb += self.rate
    def lineal_error(self, pred):
        self.error = self.out - pred
    def train(self, inputs, pred, epochs = 300):
        errors = []
        self.x11 = inputs[0]
        self.x22 = inputs[1]
        for i in range(0, epochs):
            self.wsum()
            self.sigmoid()
            self.lineal_error(pred)
            errors.append(self.error)
            if self.error == 0:
                break
            else:
                self.grlearn()
        return errors
    def use(self, inputs):
        self.x11 = inputs[0]
        self.x22 = inputs[1]
        self.wsum()
        self.sigmoid()
        return self.out



from setuptools import find_packages, setup

VERSION = '0.1.3'
PACKAGE_NAME = 'bineurones'
AUTHOR = 'Guillermo Leira Temes'
AUTHOR_EMAIL = 'guilleleiratemes@gmail.com'
URL = 'https://github.com/Guille-ux'

LICENSE = 'GPL'
DESCRIPTION = 'a libary to create neurones with two inputs'

INSTALL_REQUIRES = [
      'numpy'
      ]

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=None,
    long_description_content_type=None,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    install_requires=INSTALL_REQUIRES,
    license=LICENSE,
    packages=find_packages(),
    include_package_data=True
)



from math import exp

class Multineurone:
    def __init__(self, numinputs, rate=0.1):
        self.weights = [-1] * numinputs
        self.rate = rate
        self.ninputs = numinputs
        self.b = 1
        self.wb = -1
        self.error = 0
        self.sumw = 0
        self.out = 0

    def sigmoid(self):
        self.out = 1 / (1 + exp(-self.sumw))
        self.sumw = 0

    def wsum(self, inputs):
        self.sumw += self.b * self.wb
        for i in range(self.ninputs):
            self.sumw += self.weights[i] * inputs[i]

    def lineal_error(self, pred):
        self.error = self.out - pred

    def grlearn(self, inputs):
        self.wb -= self.rate * self.error * self.b
        for i in range(self.ninputs):
            self.weights[i] -= self.rate * self.error * inputs[i]

    def train(self, inputs, pred, epochs=300):
        errors = []
        for i in range(epochs):
            self.wsum(inputs)
            self.sigmoid()
            self.lineal_error(pred)
            errors.append(self.error)
            if self.error == 0:
                break
            else:
                self.grlearn(inputs)
        return errors

    def use(self, inputs):
        self.wsum(inputs)
        self.sigmoid()
        return self.out

